@@ -1,61 +1,70 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Return config information
-'''
+"""
 
 # Import python libs
 from __future__ import absolute_import, print_function
-import re
+
 import os
+import re
+
+import salt.syspaths as syspaths
 
 # Import salt libs
 import salt.utils.data
 import salt.utils.files
-import salt.syspaths as syspaths
 
 # Import 3rd-party libs
 from salt.ext import six
 
 # Set up the default values for all systems
-DEFAULTS = {'mongo.db': 'salt',
-            'mongo.host': 'salt',
-            'mongo.password': '',
-            'mongo.port': 27017,
-            'mongo.user': '',
-            'redis.db': '0',
-            'redis.host': 'salt',
-            'redis.port': 6379,
-            'test.foo': 'unconfigured',
-            'ca.cert_base_path': '/etc/pki',
-            'solr.cores': [],
-            'solr.host': 'localhost',
-            'solr.port': '8983',
-            'solr.baseurl': '/solr',
-            'solr.type': 'master',
-            'solr.request_timeout': None,
-            'solr.init_script': '/etc/rc.d/solr',
-            'solr.dih.import_options': {'clean': False, 'optimize': True,
-                                         'commit': True, 'verbose': False},
-            'solr.backup_path': None,
-            'solr.num_backups': 1,
-            'poudriere.config': '/usr/local/etc/poudriere.conf',
-            'poudriere.config_dir': '/usr/local/etc/poudriere.d',
-            'ldap.server': 'localhost',
-            'ldap.port': '389',
-            'ldap.tls': False,
-            'ldap.scope': 2,
-            'ldap.attrs': None,
-            'ldap.binddn': '',
-            'ldap.bindpw': '',
-            'hosts.file': '/etc/hosts',
-            'aliases.file': '/etc/aliases',
-            'virt': {'tunnel': False,
-                     'images': os.path.join(syspaths.SRV_ROOT_DIR, 'salt-images')},
-            }
+DEFAULTS = {
+    "mongo.db": "salt",
+    "mongo.host": "salt",
+    "mongo.password": "",
+    "mongo.port": 27017,
+    "mongo.user": "",
+    "redis.db": "0",
+    "redis.host": "salt",
+    "redis.port": 6379,
+    "test.foo": "unconfigured",
+    "ca.cert_base_path": "/etc/pki",
+    "solr.cores": [],
+    "solr.host": "localhost",
+    "solr.port": "8983",
+    "solr.baseurl": "/solr",
+    "solr.type": "master",
+    "solr.request_timeout": None,
+    "solr.init_script": "/etc/rc.d/solr",
+    "solr.dih.import_options": {
+        "clean": False,
+        "optimize": True,
+        "commit": True,
+        "verbose": False,
+    },
+    "solr.backup_path": None,
+    "solr.num_backups": 1,
+    "poudriere.config": "/usr/local/etc/poudriere.conf",
+    "poudriere.config_dir": "/usr/local/etc/poudriere.d",
+    "ldap.server": "localhost",
+    "ldap.port": "389",
+    "ldap.tls": False,
+    "ldap.scope": 2,
+    "ldap.attrs": None,
+    "ldap.binddn": "",
+    "ldap.bindpw": "",
+    "hosts.file": "/etc/hosts",
+    "aliases.file": "/etc/aliases",
+    "virt": {
+        "tunnel": False,
+        "images": os.path.join(syspaths.SRV_ROOT_DIR, "salt-images"),
+    },
+}
 
 
-def backup_mode(backup=''):
-    '''
+def backup_mode(backup=""):
+    """
     Return the backup mode
 
     CLI Example:
@@ -63,14 +72,14 @@ def backup_mode(backup=''):
     .. code-block:: bash
 
         salt '*' config.backup_mode
-    '''
+    """
     if backup:
         return backup
-    return option('backup_mode')
+    return option("backup_mode")
 
 
 def manage_mode(mode):
-    '''
+    """
     Return a mode value, normalized to a string
 
     CLI Example:
@@ -78,7 +87,7 @@ def manage_mode(mode):
     .. code-block:: bash
 
         salt '*' config.manage_mode
-    '''
+    """
     # config.manage_mode should no longer be invoked from the __salt__ dunder
     # in Salt code, this function is only being left here for backwards
     # compatibility.
@@ -86,7 +95,7 @@ def manage_mode(mode):
 
 
 def valid_fileproto(uri):
-    '''
+    """
     Returns a boolean value based on whether or not the URI passed has a valid
     remote file protocol designation
 
@@ -95,20 +104,15 @@ def valid_fileproto(uri):
     .. code-block:: bash
 
         salt '*' config.valid_fileproto salt://path/to/file
-    '''
+    """
     try:
-        return bool(re.match('^(?:salt|https?|ftp)://', uri))
-    except Exception:
+        return bool(re.match("^(?:salt|https?|ftp)://", uri))
+    except Exception:  # pylint: disable=broad-except
         return False
 
 
-def option(
-        value,
-        default='',
-        omit_opts=False,
-        omit_master=False,
-        omit_pillar=False):
-    '''
+def option(value, default="", omit_opts=False, omit_master=False, omit_pillar=False):
+    """
     Pass in a generic option and receive the value that will be assigned
 
     CLI Example:
@@ -116,13 +120,13 @@ def option(
     .. code-block:: bash
 
         salt '*' config.option redis.host
-    '''
+    """
     if not omit_opts:
         if value in __opts__:
             return __opts__[value]
     if not omit_master:
-        if value in __pillar__.get('master', {}):
-            return __pillar__['master'][value]
+        if value in __pillar__.get("master", {}):
+            return __pillar__["master"][value]
     if not omit_pillar:
         if value in __pillar__:
             return __pillar__[value]
@@ -131,12 +135,8 @@ def option(
     return default
 
 
-def merge(value,
-          default='',
-          omit_opts=False,
-          omit_master=False,
-          omit_pillar=False):
-    '''
+def merge(value, default="", omit_opts=False, omit_master=False, omit_pillar=False):
+    """
     Retrieves an option based on key, merging all matches.
 
     Same as ``option()`` except that it merges all matches, rather than taking
@@ -147,7 +147,7 @@ def merge(value,
     .. code-block:: bash
 
         salt '*' config.merge schedule
-    '''
+    """
     ret = None
     if not omit_opts:
         if value in __opts__:
@@ -155,8 +155,8 @@ def merge(value,
             if isinstance(ret, six.string_types):
                 return ret
     if not omit_master:
-        if value in __pillar__.get('master', {}):
-            tmp = __pillar__['master'][value]
+        if value in __pillar__.get("master", {}):
+            tmp = __pillar__["master"][value]
             if ret is None:
                 ret = tmp
                 if isinstance(ret, six.string_types):
@@ -164,8 +164,7 @@ def merge(value,
             elif isinstance(ret, dict) and isinstance(tmp, dict):
                 tmp.update(ret)
                 ret = tmp
-            elif (isinstance(ret, (list, tuple)) and
-                    isinstance(tmp, (list, tuple))):
+            elif isinstance(ret, (list, tuple)) and isinstance(tmp, (list, tuple)):
                 ret = list(ret) + list(tmp)
     if not omit_pillar:
         if value in __pillar__:
@@ -177,16 +176,15 @@ def merge(value,
             elif isinstance(ret, dict) and isinstance(tmp, dict):
                 tmp.update(ret)
                 ret = tmp
-            elif (isinstance(ret, (list, tuple)) and
-                    isinstance(tmp, (list, tuple))):
+            elif isinstance(ret, (list, tuple)) and isinstance(tmp, (list, tuple)):
                 ret = list(ret) + list(tmp)
     if ret is None and value in DEFAULTS:
         return DEFAULTS[value]
     return ret or default
 
 
-def get(key, default=''):
-    '''
+def get(key, default=""):
+    """
     .. versionadded: 0.14.0
 
     Attempt to retrieve the named value from opts, pillar, grains of the master
@@ -215,24 +213,26 @@ def get(key, default=''):
     .. code-block:: bash
 
         salt '*' config.get pkg:apache
-    '''
-    ret = salt.utils.data.traverse_dict_and_list(__opts__, key, '_|-')
-    if ret != '_|-':
+    """
+    ret = salt.utils.data.traverse_dict_and_list(__opts__, key, "_|-")
+    if ret != "_|-":
         return ret
-    ret = salt.utils.data.traverse_dict_and_list(__grains__, key, '_|-')
-    if ret != '_|-':
+    ret = salt.utils.data.traverse_dict_and_list(__grains__, key, "_|-")
+    if ret != "_|-":
         return ret
-    ret = salt.utils.data.traverse_dict_and_list(__pillar__, key, '_|-')
-    if ret != '_|-':
+    ret = salt.utils.data.traverse_dict_and_list(__pillar__, key, "_|-")
+    if ret != "_|-":
         return ret
-    ret = salt.utils.data.traverse_dict_and_list(__pillar__.get('master', {}), key, '_|-')
-    if ret != '_|-':
+    ret = salt.utils.data.traverse_dict_and_list(
+        __pillar__.get("master", {}), key, "_|-"
+    )
+    if ret != "_|-":
         return ret
     return default
 
 
 def dot_vals(value):
-    '''
+    """
     Pass in a configuration value that should be preceded by the module name
     and a dot, this will return a list of all read key/value pairs
 
@@ -241,12 +241,12 @@ def dot_vals(value):
     .. code-block:: bash
 
         salt '*' config.dot_vals host
-    '''
+    """
     ret = {}
-    for key, val in six.iteritems(__pillar__.get('master', {})):
-        if key.startswith('{0}.'.format(value)):
+    for key, val in six.iteritems(__pillar__.get("master", {})):
+        if key.startswith("{0}.".format(value)):
             ret[key] = val
     for key, val in six.iteritems(__opts__):
-        if key.startswith('{0}.'.format(value)):
+        if key.startswith("{0}.".format(value)):
             ret[key] = val
     return ret
