@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 This is the default pillar exact matcher for compound matches.
 
 There is no minion-side equivalent for this, so consequently there is no ``match()``
 function below, only an ``mmatch()``
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
@@ -15,12 +15,11 @@ log = logging.getLogger(__name__)
 
 
 def mmatch(expr, delimiter, greedy, opts=None):
-    '''
+    """
     Return the minions found by looking via pillar
-    '''
+    """
     if not opts:
         opts = __opts__
 
     ckminions = salt.utils.minions.CkMinions(opts)
-    return ckminions._check_compound_minions(expr, delimiter, greedy,
-                                             pillar_exact=True)
+    return ckminions._check_compound_minions(expr, delimiter, greedy, pillar_exact=True)
