@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Azure (ARM) Compute Execution Module
 
 .. versionadded:: 2019.2.0
@@ -44,10 +44,11 @@ Azure (ARM) Compute Execution Module
       * ``AZURE_US_GOV_CLOUD``
       * ``AZURE_GERMAN_CLOUD``
 
-'''
+"""
 
 # Python libs
 from __future__ import absolute_import
+
 import logging
 
 # Azure libs
@@ -56,11 +57,12 @@ try:
     import azure.mgmt.compute.models  # pylint: disable=unused-import
     from msrest.exceptions import SerializationError
     from msrestazure.azure_exceptions import CloudError
+
     HAS_LIBS = True
 except ImportError:
     pass
 
-__virtualname__ = 'azurearm_compute'
+__virtualname__ = "azurearm_compute"
 
 log = logging.getLogger(__name__)
 
@@ -69,16 +71,18 @@ def __virtual__():
     if not HAS_LIBS:
         return (
             False,
-            'The following dependencies are required to use the AzureARM modules: '
-            'Microsoft Azure SDK for Python >= 2.0rc6, '
-            'MS REST Azure (msrestazure) >= 0.4'
+            "The following dependencies are required to use the AzureARM modules: "
+            "Microsoft Azure SDK for Python >= 2.0rc6, "
+            "MS REST Azure (msrestazure) >= 0.4",
         )
 
     return __virtualname__
 
 
-def availability_set_create_or_update(name, resource_group, **kwargs):  # pylint: disable=invalid-name
-    '''
+def availability_set_create_or_update(
+    name, resource_group, **kwargs
+):  # pylint: disable=invalid-name
+    """
     .. versionadded:: 2019.2.0
 
     Create or update an availability set.
@@ -94,59 +98,61 @@ def availability_set_create_or_update(name, resource_group, **kwargs):  # pylint
 
         salt-call azurearm_compute.availability_set_create_or_update testset testgroup
 
-    '''
-    if 'location' not in kwargs:
-        rg_props = __salt__['azurearm_resource.resource_group_get'](
+    """
+    if "location" not in kwargs:
+        rg_props = __salt__["azurearm_resource.resource_group_get"](
             resource_group, **kwargs
         )
 
-        if 'error' in rg_props:
-            log.error(
-                'Unable to determine location from resource group specified.'
-            )
+        if "error" in rg_props:
+            log.error("Unable to determine location from resource group specified.")
             return False
-        kwargs['location'] = rg_props['location']
+        kwargs["location"] = rg_props["location"]
 
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
 
     # Use VM names to link to the IDs of existing VMs.
-    if isinstance(kwargs.get('virtual_machines'), list):
+    if isinstance(kwargs.get("virtual_machines"), list):
         vm_list = []
-        for vm_name in kwargs.get('virtual_machines'):
-            vm_instance = __salt__['azurearm_compute.virtual_machine_get'](
-                name=vm_name,
-                resource_group=resource_group,
-                **kwargs
+        for vm_name in kwargs.get("virtual_machines"):
+            vm_instance = __salt__["azurearm_compute.virtual_machine_get"](
+                name=vm_name, resource_group=resource_group, **kwargs
             )
-            if 'error' not in vm_instance:
-                vm_list.append({'id': str(vm_instance['id'])})
-        kwargs['virtual_machines'] = vm_list
+            if "error" not in vm_instance:
+                vm_list.append({"id": str(vm_instance["id"])})
+        kwargs["virtual_machines"] = vm_list
 
     try:
-        setmodel = __utils__['azurearm.create_object_model']('compute', 'AvailabilitySet', **kwargs)
+        setmodel = __utils__["azurearm.create_object_model"](
+            "compute", "AvailabilitySet", **kwargs
+        )
     except TypeError as exc:
-        result = {'error': 'The object model could not be built. ({0})'.format(str(exc))}
+        result = {
+            "error": "The object model could not be built. ({0})".format(str(exc))
+        }
         return result
 
     try:
         av_set = compconn.availability_sets.create_or_update(
             resource_group_name=resource_group,
             availability_set_name=name,
-            parameters=setmodel
+            parameters=setmodel,
         )
         result = av_set.as_dict()
 
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
     except SerializationError as exc:
-        result = {'error': 'The object model could not be parsed. ({0})'.format(str(exc))}
+        result = {
+            "error": "The object model could not be parsed. ({0})".format(str(exc))
+        }
 
     return result
 
 
 def availability_set_delete(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Delete an availability set.
@@ -162,24 +168,23 @@ def availability_set_delete(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.availability_set_delete testset testgroup
 
-    '''
+    """
     result = False
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         compconn.availability_sets.delete(
-            resource_group_name=resource_group,
-            availability_set_name=name
+            resource_group_name=resource_group, availability_set_name=name
         )
         result = True
 
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
 
     return result
 
 
 def availability_set_get(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Get a dictionary representing an availability set's properties.
@@ -195,24 +200,23 @@ def availability_set_get(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.availability_set_get testset testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         av_set = compconn.availability_sets.get(
-            resource_group_name=resource_group,
-            availability_set_name=name
+            resource_group_name=resource_group, availability_set_name=name
         )
         result = av_set.as_dict()
 
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def availability_sets_list(resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     List all availability sets within a resource group.
@@ -226,27 +230,27 @@ def availability_sets_list(resource_group, **kwargs):
 
         salt-call azurearm_compute.availability_sets_list testgroup
 
-    '''
+    """
     result = {}
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
-        avail_sets = __utils__['azurearm.paged_object_to_list'](
-            compconn.availability_sets.list(
-                resource_group_name=resource_group
-            )
+        avail_sets = __utils__["azurearm.paged_object_to_list"](
+            compconn.availability_sets.list(resource_group_name=resource_group)
         )
 
         for avail_set in avail_sets:
-            result[avail_set['name']] = avail_set
+            result[avail_set["name"]] = avail_set
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
-def availability_sets_list_available_sizes(name, resource_group, **kwargs):  # pylint: disable=invalid-name
-    '''
+def availability_sets_list_available_sizes(
+    name, resource_group, **kwargs
+):  # pylint: disable=invalid-name
+    """
     .. versionadded:: 2019.2.0
 
     List all available virtual machine sizes that can be used to
@@ -264,28 +268,29 @@ def availability_sets_list_available_sizes(name, resource_group, **kwargs):  # p
 
         salt-call azurearm_compute.availability_sets_list_available_sizes testset testgroup
 
-    '''
+    """
     result = {}
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
-        sizes = __utils__['azurearm.paged_object_to_list'](
+        sizes = __utils__["azurearm.paged_object_to_list"](
             compconn.availability_sets.list_available_sizes(
-                resource_group_name=resource_group,
-                availability_set_name=name
+                resource_group_name=resource_group, availability_set_name=name
             )
         )
 
         for size in sizes:
-            result[size['name']] = size
+            result[size["name"]] = size
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
-def virtual_machine_capture(name, destination_name, resource_group, prefix='capture-', overwrite=False, **kwargs):
-    '''
+def virtual_machine_capture(
+    name, destination_name, resource_group, prefix="capture-", overwrite=False, **kwargs
+):
+    """
     .. versionadded:: 2019.2.0
 
     Captures the VM by copying virtual hard disks of the VM and outputs
@@ -308,13 +313,13 @@ def virtual_machine_capture(name, destination_name, resource_group, prefix='capt
 
         salt-call azurearm_compute.virtual_machine_capture testvm testcontainer testgroup
 
-    '''
+    """
     # pylint: disable=invalid-name
     VirtualMachineCaptureParameters = getattr(
-        azure.mgmt.compute.models, 'VirtualMachineCaptureParameters'
+        azure.mgmt.compute.models, "VirtualMachineCaptureParameters"
     )
 
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.capture(
@@ -323,21 +328,21 @@ def virtual_machine_capture(name, destination_name, resource_group, prefix='capt
             parameters=VirtualMachineCaptureParameters(
                 vhd_prefix=prefix,
                 destination_container_name=destination_name,
-                overwrite_vhds=overwrite
-            )
+                overwrite_vhds=overwrite,
+            ),
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_get(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Retrieves information about the model view or the instance view of a
@@ -354,27 +359,27 @@ def virtual_machine_get(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_get testvm testgroup
 
-    '''
-    expand = kwargs.get('expand')
+    """
+    expand = kwargs.get("expand")
 
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.get(
-            resource_group_name=resource_group,
-            vm_name=name,
-            expand=expand
+            resource_group_name=resource_group, vm_name=name, expand=expand
         )
         result = vm.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
-def virtual_machine_convert_to_managed_disks(name, resource_group, **kwargs):  # pylint: disable=invalid-name
-    '''
+def virtual_machine_convert_to_managed_disks(
+    name, resource_group, **kwargs
+):  # pylint: disable=invalid-name
+    """
     .. versionadded:: 2019.2.0
 
     Converts virtual machine disks from blob-based to managed disks. Virtual
@@ -391,26 +396,25 @@ def virtual_machine_convert_to_managed_disks(name, resource_group, **kwargs):  #
 
         salt-call azurearm_compute.virtual_machine_convert_to_managed_disks testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.convert_to_managed_disks(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_deallocate(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Power off a virtual machine and deallocate compute resources.
@@ -426,26 +430,25 @@ def virtual_machine_deallocate(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_deallocate testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.deallocate(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_generalize(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Set the state of a virtual machine to 'generalized'.
@@ -461,23 +464,22 @@ def virtual_machine_generalize(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_generalize testvm testgroup
 
-    '''
+    """
     result = False
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         compconn.virtual_machines.generalize(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         result = True
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
 
     return result
 
 
 def virtual_machines_list(resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     List all virtual machines within a resource group.
@@ -491,26 +493,24 @@ def virtual_machines_list(resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machines_list testgroup
 
-    '''
+    """
     result = {}
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
-        vms = __utils__['azurearm.paged_object_to_list'](
-            compconn.virtual_machines.list(
-                resource_group_name=resource_group
-            )
+        vms = __utils__["azurearm.paged_object_to_list"](
+            compconn.virtual_machines.list(resource_group_name=resource_group)
         )
         for vm in vms:  # pylint: disable=invalid-name
-            result[vm['name']] = vm
+            result[vm["name"]] = vm
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machines_list_all(**kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     List all virtual machines within a subscription.
@@ -521,24 +521,26 @@ def virtual_machines_list_all(**kwargs):
 
         salt-call azurearm_compute.virtual_machines_list_all
 
-    '''
+    """
     result = {}
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
-        vms = __utils__['azurearm.paged_object_to_list'](
+        vms = __utils__["azurearm.paged_object_to_list"](
             compconn.virtual_machines.list_all()
         )
         for vm in vms:  # pylint: disable=invalid-name
-            result[vm['name']] = vm
+            result[vm["name"]] = vm
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
-def virtual_machines_list_available_sizes(name, resource_group, **kwargs):  # pylint: disable=invalid-name
-    '''
+def virtual_machines_list_available_sizes(
+    name, resource_group, **kwargs
+):  # pylint: disable=invalid-name
+    """
     .. versionadded:: 2019.2.0
 
     Lists all available virtual machine sizes to which the specified virtual
@@ -555,27 +557,26 @@ def virtual_machines_list_available_sizes(name, resource_group, **kwargs):  # py
 
         salt-call azurearm_compute.virtual_machines_list_available_sizes testvm testgroup
 
-    '''
+    """
     result = {}
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
-        sizes = __utils__['azurearm.paged_object_to_list'](
+        sizes = __utils__["azurearm.paged_object_to_list"](
             compconn.virtual_machines.list_available_sizes(
-                resource_group_name=resource_group,
-                vm_name=name
+                resource_group_name=resource_group, vm_name=name
             )
         )
         for size in sizes:
-            result[size['name']] = size
+            result[size["name"]] = size
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_power_off(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Power off (stop) a virtual machine.
@@ -591,26 +592,25 @@ def virtual_machine_power_off(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_power_off testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.power_off(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_restart(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Restart a virtual machine.
@@ -626,26 +626,25 @@ def virtual_machine_restart(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_restart testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.restart(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_start(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Power on (start) a virtual machine.
@@ -661,26 +660,25 @@ def virtual_machine_start(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_start testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.start(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
 
 
 def virtual_machine_redeploy(name, resource_group, **kwargs):
-    '''
+    """
     .. versionadded:: 2019.2.0
 
     Redeploy a virtual machine.
@@ -696,19 +694,18 @@ def virtual_machine_redeploy(name, resource_group, **kwargs):
 
         salt-call azurearm_compute.virtual_machine_redeploy testvm testgroup
 
-    '''
-    compconn = __utils__['azurearm.get_client']('compute', **kwargs)
+    """
+    compconn = __utils__["azurearm.get_client"]("compute", **kwargs)
     try:
         # pylint: disable=invalid-name
         vm = compconn.virtual_machines.redeploy(
-            resource_group_name=resource_group,
-            vm_name=name
+            resource_group_name=resource_group, vm_name=name
         )
         vm.wait()
         vm_result = vm.result()
         result = vm_result.as_dict()
     except CloudError as exc:
-        __utils__['azurearm.log_cloud_error']('compute', str(exc), **kwargs)
-        result = {'error': str(exc)}
+        __utils__["azurearm.log_cloud_error"]("compute", str(exc), **kwargs)
+        result = {"error": str(exc)}
 
     return result
