@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
 Connection module for Amazon ALB
 
 .. versionadded:: 2017.7.0
@@ -36,63 +35,65 @@ Connection module for Amazon ALB
 
 :depends: boto3
 
-'''
+"""
 # keep lint from choking on _get_conn and _cache_id
 # pylint: disable=E0602
 
-from __future__ import absolute_import, print_function, unicode_literals
-
 # Import Python libs
 import logging
 
+# Import Salt libs
+import salt.utils.boto3mod
+import salt.utils.versions
+
 log = logging.getLogger(__name__)
 
-# Import Salt libs
-from salt.ext import six
-import salt.utils.versions
 
 # Import third-party libs
 try:
     # pylint: disable=unused-import
-    import salt.utils.boto3
     import boto3
     import botocore
+
     # pylint: enable=unused-import
 
     # TODO Version check using salt.utils.versions
     from botocore.exceptions import ClientError
-    logging.getLogger('boto3').setLevel(logging.CRITICAL)
+
+    logging.getLogger("boto3").setLevel(logging.CRITICAL)
     HAS_BOTO = True
 except ImportError:
     HAS_BOTO = False
 
 
 def __virtual__():
-    '''
+    """
     Only load if boto3 libraries exist.
-    '''
+    """
     has_boto_reqs = salt.utils.versions.check_boto_reqs()
     if has_boto_reqs is True:
-        __utils__['boto3.assign_funcs'](__name__, 'elbv2')
+        salt.utils.boto3mod.assign_funcs(__name__, "elbv2")
     return has_boto_reqs
 
 
-def create_target_group(name,
-                        protocol,
-                        port,
-                        vpc_id,
-                        region=None,
-                        key=None,
-                        keyid=None,
-                        profile=None,
-                        health_check_protocol='HTTP',
-                        health_check_port='traffic-port',
-                        health_check_path='/',
-                        health_check_interval_seconds=30,
-                        health_check_timeout_seconds=5,
-                        healthy_threshold_count=5,
-                        unhealthy_threshold_count=2):
-    '''
+def create_target_group(
+    name,
+    protocol,
+    port,
+    vpc_id,
+    region=None,
+    key=None,
+    keyid=None,
+    profile=None,
+    health_check_protocol="HTTP",
+    health_check_port="traffic-port",
+    health_check_path="/",
+    health_check_interval_seconds=30,
+    health_check_timeout_seconds=5,
+    healthy_threshold_count=5,
+    unhealthy_threshold_count=2,
+):
+    """
     Create target group if not present.
 
     name
@@ -134,42 +135,46 @@ def create_target_group(name,
     .. code-block:: bash
 
         salt myminion boto_elbv2.create_target_group learn1give1 protocol=HTTP port=54006 vpc_id=vpc-deadbeef
-    '''
+    """
 
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
     if target_group_exists(name, region, key, keyid, profile):
         return True
 
     try:
-        alb = conn.create_target_group(Name=name, Protocol=protocol, Port=port,
-                                       VpcId=vpc_id, HealthCheckProtocol=health_check_protocol,
-                                       HealthCheckPort=health_check_port,
-                                       HealthCheckPath=health_check_path,
-                                       HealthCheckIntervalSeconds=health_check_interval_seconds,
-                                       HealthCheckTimeoutSeconds=health_check_timeout_seconds,
-                                       HealthyThresholdCount=healthy_threshold_count,
-                                       UnhealthyThresholdCount=unhealthy_threshold_count)
+        alb = conn.create_target_group(
+            Name=name,
+            Protocol=protocol,
+            Port=port,
+            VpcId=vpc_id,
+            HealthCheckProtocol=health_check_protocol,
+            HealthCheckPort=health_check_port,
+            HealthCheckPath=health_check_path,
+            HealthCheckIntervalSeconds=health_check_interval_seconds,
+            HealthCheckTimeoutSeconds=health_check_timeout_seconds,
+            HealthyThresholdCount=healthy_threshold_count,
+            UnhealthyThresholdCount=unhealthy_threshold_count,
+        )
         if alb:
-            log.info('Created ALB %s: %s', name, alb['TargetGroups'][0]['TargetGroupArn'])
+            log.info(
+                "Created ALB %s: %s", name, alb["TargetGroups"][0]["TargetGroupArn"]
+            )
             return True
         else:
-            log.error('Failed to create ALB %s', name)
+            log.error("Failed to create ALB %s", name)
             return False
     except ClientError as error:
         log.error(
-            'Failed to create ALB %s: %s: %s',
-            name, error.response['Error']['Code'],
-            error.response['Error']['Message'],
-            exc_info_on_loglevel=logging.DEBUG
+            "Failed to create ALB %s: %s: %s",
+            name,
+            error.response["Error"]["Code"],
+            error.response["Error"]["Message"],
+            exc_info_on_loglevel=logging.DEBUG,
         )
 
 
-def delete_target_group(name,
-                        region=None,
-                        key=None,
-                        keyid=None,
-                        profile=None):
-    '''
+def delete_target_group(name, region=None, key=None, keyid=None, profile=None):
+    """
     Delete target group.
 
     name
@@ -183,36 +188,33 @@ def delete_target_group(name,
     .. code-block:: bash
 
         salt myminion boto_elbv2.delete_target_group arn:aws:elasticloadbalancing:us-west-2:644138682826:targetgroup/learn1give1-api/414788a16b5cf163
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     if not target_group_exists(name, region, key, keyid, profile):
         return True
 
     try:
-        if name.startswith('arn:aws:elasticloadbalancing'):
+        if name.startswith("arn:aws:elasticloadbalancing"):
             conn.delete_target_group(TargetGroupArn=name)
-            log.info('Deleted target group %s', name)
+            log.info("Deleted target group %s", name)
         else:
             tg_info = conn.describe_target_groups(Names=[name])
-            if len(tg_info['TargetGroups']) != 1:
+            if len(tg_info["TargetGroups"]) != 1:
                 return False
-            arn = tg_info['TargetGroups'][0]['TargetGroupArn']
+            arn = tg_info["TargetGroups"][0]["TargetGroupArn"]
             conn.delete_target_group(TargetGroupArn=arn)
-            log.info('Deleted target group %s ARN %s', name, arn)
+            log.info("Deleted target group %s ARN %s", name, arn)
         return True
     except ClientError as error:
-        log.error('Failed to delete target group %s', name,
-                  exc_info_on_loglevel=logging.DEBUG)
+        log.error(
+            "Failed to delete target group %s", name, exc_info_on_loglevel=logging.DEBUG
+        )
         return False
 
 
-def target_group_exists(name,
-                        region=None,
-                        key=None,
-                        keyid=None,
-                        profile=None):
-    '''
+def target_group_exists(name, region=None, key=None, keyid=None, profile=None):
+    """
     Check to see if an target group exists.
 
     CLI example:
@@ -220,31 +222,28 @@ def target_group_exists(name,
     .. code-block:: bash
 
         salt myminion boto_elbv2.target_group_exists arn:aws:elasticloadbalancing:us-west-2:644138682826:targetgroup/learn1give1-api/414788a16b5cf163
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     try:
-        if name.startswith('arn:aws:elasticloadbalancing'):
+        if name.startswith("arn:aws:elasticloadbalancing"):
             alb = conn.describe_target_groups(TargetGroupArns=[name])
         else:
             alb = conn.describe_target_groups(Names=[name])
         if alb:
             return True
         else:
-            log.warning('The target group does not exist in region %s', region)
+            log.warning("The target group does not exist in region %s", region)
             return False
     except ClientError as error:
-        log.warning('target_group_exists check for %s returned: %s', name, error)
+        log.warning("target_group_exists check for %s returned: %s", name, error)
         return False
 
 
-def describe_target_health(name,
-                           targets=None,
-                           region=None,
-                           key=None,
-                           keyid=None,
-                           profile=None):
-    '''
+def describe_target_health(
+    name, targets=None, region=None, key=None, keyid=None, profile=None
+):
+    """
     Get the curret health check status for targets in a target group.
 
     CLI example:
@@ -252,7 +251,7 @@ def describe_target_health(name,
     .. code-block:: bash
 
         salt myminion boto_elbv2.describe_target_health arn:aws:elasticloadbalancing:us-west-2:644138682826:targetgroup/learn1give1-api/414788a16b5cf163 targets=["i-isdf23ifjf"]
-    '''
+    """
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     try:
@@ -260,12 +259,14 @@ def describe_target_health(name,
             targetsdict = []
             for target in targets:
                 targetsdict.append({"Id": target})
-            instances = conn.describe_target_health(TargetGroupArn=name, Targets=targetsdict)
+            instances = conn.describe_target_health(
+                TargetGroupArn=name, Targets=targetsdict
+            )
         else:
             instances = conn.describe_target_health(TargetGroupArn=name)
         ret = {}
-        for instance in instances['TargetHealthDescriptions']:
-            ret.update({instance['Target']['Id']: instance['TargetHealth']['State']})
+        for instance in instances["TargetHealthDescriptions"]:
+            ret.update({instance["Target"]["Id"]: instance["TargetHealth"]["State"]})
 
         return ret
     except ClientError as error:
@@ -273,13 +274,8 @@ def describe_target_health(name,
         return {}
 
 
-def register_targets(name,
-                     targets,
-                     region=None,
-                     key=None,
-                     keyid=None,
-                     profile=None):
-    '''
+def register_targets(name, targets, region=None, key=None, keyid=None, profile=None):
+    """
     Register targets to a target froup of an ALB. ``targets`` is either a
     instance id string or a list of instance id's.
 
@@ -294,9 +290,9 @@ def register_targets(name,
 
         salt myminion boto_elbv2.register_targets myelb instance_id
         salt myminion boto_elbv2.register_targets myelb "[instance_id,instance_id]"
-    '''
+    """
     targetsdict = []
-    if isinstance(targets, six.string_types) or isinstance(targets, six.text_type):
+    if isinstance(targets, str):
         targetsdict.append({"Id": targets})
     else:
         for target in targets:
@@ -304,7 +300,9 @@ def register_targets(name,
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     try:
-        registered_targets = conn.register_targets(TargetGroupArn=name, Targets=targetsdict)
+        registered_targets = conn.register_targets(
+            TargetGroupArn=name, Targets=targetsdict
+        )
         if registered_targets:
             return True
         return False
@@ -313,13 +311,8 @@ def register_targets(name,
         return False
 
 
-def deregister_targets(name,
-                       targets,
-                       region=None,
-                       key=None,
-                       keyid=None,
-                       profile=None):
-    '''
+def deregister_targets(name, targets, region=None, key=None, keyid=None, profile=None):
+    """
     Deregister targets to a target froup of an ALB. ``targets`` is either a
     instance id string or a list of instance id's.
 
@@ -334,9 +327,9 @@ def deregister_targets(name,
 
         salt myminion boto_elbv2.deregister_targets myelb instance_id
         salt myminion boto_elbv2.deregister_targets myelb "[instance_id,instance_id]"
-    '''
+    """
     targetsdict = []
-    if isinstance(targets, six.string_types) or isinstance(targets, six.text_type):
+    if isinstance(targets, str):
         targetsdict.append({"Id": targets})
     else:
         for target in targets:
@@ -344,7 +337,9 @@ def deregister_targets(name,
     conn = _get_conn(region=region, key=key, keyid=keyid, profile=profile)
 
     try:
-        registered_targets = conn.deregister_targets(TargetGroupArn=name, Targets=targetsdict)
+        registered_targets = conn.deregister_targets(
+            TargetGroupArn=name, Targets=targetsdict
+        )
         if registered_targets:
             return True
         return False
