@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Chronos
 ========
 
@@ -23,16 +23,16 @@ the chronos endpoint:
       base_url: http://my-chronos-master.mydomain.com:4400
 
 .. versionadded:: 2015.8.2
-'''
-from __future__ import absolute_import
+"""
+from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
+
 import salt.utils.http
 
-
-__proxyenabled__ = ['chronos']
+__proxyenabled__ = ["chronos"]
 CONFIG = {}
-CONFIG_BASE_URL = 'base_url'
+CONFIG_BASE_URL = "base_url"
 log = logging.getLogger(__file__)
 
 
@@ -41,43 +41,40 @@ def __virtual__():
 
 
 def init(opts):
-    '''
+    """
     Perform any needed setup.
-    '''
-    if CONFIG_BASE_URL in opts['proxy']:
-        CONFIG[CONFIG_BASE_URL] = opts['proxy'][CONFIG_BASE_URL]
+    """
+    if CONFIG_BASE_URL in opts["proxy"]:
+        CONFIG[CONFIG_BASE_URL] = opts["proxy"][CONFIG_BASE_URL]
     else:
-        log.error('missing proxy property %s', CONFIG_BASE_URL)
-    log.debug('CONFIG: %s', CONFIG)
+        log.error("missing proxy property %s", CONFIG_BASE_URL)
+    log.debug("CONFIG: %s", CONFIG)
 
 
 def ping():
-    '''
+    """
     Is the chronos api responding?
-    '''
+    """
     try:
         response = salt.utils.http.query(
             "{0}/scheduler/jobs".format(CONFIG[CONFIG_BASE_URL]),
-            decode_type='json',
+            decode_type="json",
             decode=True,
         )
         log.debug(
-            'chronos.info returned succesfully: %s',
-            response,
+            "chronos.info returned successfully: %s", response,
         )
-        if 'dict' in response:
+        if "dict" in response:
             return True
-    except Exception as ex:
+    except Exception as ex:  # pylint: disable=broad-except
         log.error(
-            'error pinging chronos with base_url %s: %s',
-            CONFIG[CONFIG_BASE_URL],
-            ex,
+            "error pinging chronos with base_url %s: %s", CONFIG[CONFIG_BASE_URL], ex,
         )
     return False
 
 
 def shutdown(opts):
-    '''
+    """
     For this proxy shutdown is a no-op
-    '''
-    log.debug('chronos proxy shutdown() called...')
+    """
+    log.debug("chronos proxy shutdown() called...")
