@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Installation of Composer Packages
 =================================
 
@@ -36,7 +36,7 @@ the location of composer in the state.
         - composer: /path/to/composer.phar
         - php: /usr/local/bin/php
         - no_dev: true
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 # Import salt libs
@@ -44,27 +44,31 @@ from salt.exceptions import SaltException
 
 
 def __virtual__():
-    '''
+    """
     Only load if the composer module is available in __salt__
-    '''
-    return 'composer.install' in __salt__
+    """
+    if "composer.install" in __salt__:
+        return True
+    return (False, "composer module could not be loaded")
 
 
-def installed(name,
-              composer=None,
-              php=None,
-              user=None,
-              prefer_source=None,
-              prefer_dist=None,
-              no_scripts=None,
-              no_plugins=None,
-              optimize=None,
-              no_dev=None,
-              quiet=False,
-              composer_home='/root',
-              always_check=True,
-              env=None):
-    '''
+def installed(
+    name,
+    composer=None,
+    php=None,
+    user=None,
+    prefer_source=None,
+    prefer_dist=None,
+    no_scripts=None,
+    no_plugins=None,
+    optimize=None,
+    no_dev=None,
+    quiet=False,
+    composer_home="/root",
+    always_check=True,
+    env=None,
+):
+    """
     Verify that the correct versions of composer dependencies are present.
 
     name
@@ -115,37 +119,39 @@ def installed(name,
 
     env
         A list of environment variables to be set prior to execution.
-    '''
-    ret = {'name': name, 'result': None, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": None, "comment": "", "changes": {}}
 
-    did_install = __salt__['composer.did_composer_install'](name)
+    did_install = __salt__["composer.did_composer_install"](name)
 
     # Check if composer.lock exists, if so we already ran `composer install`
     # and we don't need to do it again
     if always_check is False and did_install:
-        ret['result'] = True
-        ret['comment'] = 'Composer already installed this directory'
+        ret["result"] = True
+        ret["comment"] = "Composer already installed this directory"
         return ret
 
     # The state of the system does need to be changed. Check if we're running
     # in ``test=true`` mode.
-    if __opts__['test'] is True:
+    if __opts__["test"] is True:
 
         if did_install is True:
             install_status = ""
         else:
             install_status = "not "
 
-        ret['comment'] = 'The state of "{0}" will be changed.'.format(name)
-        ret['changes'] = {
-            'old': 'composer install has {0}been run in {1}'.format(install_status, name),
-            'new': 'composer install will be run in {0}'.format(name)
+        ret["comment"] = 'The state of "{0}" will be changed.'.format(name)
+        ret["changes"] = {
+            "old": "composer install has {0}been run in {1}".format(
+                install_status, name
+            ),
+            "new": "composer install will be run in {0}".format(name),
         }
-        ret['result'] = None
+        ret["result"] = None
         return ret
 
     try:
-        call = __salt__['composer.install'](
+        call = __salt__["composer.install"](
             name,
             composer=composer,
             php=php,
@@ -158,44 +164,45 @@ def installed(name,
             no_dev=no_dev,
             quiet=quiet,
             composer_home=composer_home,
-            env=env
+            env=env,
         )
     except (SaltException) as err:
-        ret['result'] = False
-        ret['comment'] = 'Error executing composer in \'{0}\': {1}'.format(name, err)
+        ret["result"] = False
+        ret["comment"] = "Error executing composer in '{0}': {1}".format(name, err)
         return ret
 
     # If composer retcode != 0 then an exception was thrown and we dealt with it.
     # Any other case is success, regardless of what composer decides to output.
 
-    ret['result'] = True
+    ret["result"] = True
 
     if quiet is True:
-        ret['comment'] = 'Composer install completed successfully, output silenced by quiet flag'
+        ret[
+            "comment"
+        ] = "Composer install completed successfully, output silenced by quiet flag"
     else:
-        ret['comment'] = 'Composer install completed successfully'
-        ret['changes'] = {
-            'stderr': call['stderr'],
-            'stdout': call['stdout']
-        }
+        ret["comment"] = "Composer install completed successfully"
+        ret["changes"] = {"stderr": call["stderr"], "stdout": call["stdout"]}
 
     return ret
 
 
-def update(name,
-           composer=None,
-           php=None,
-           user=None,
-           prefer_source=None,
-           prefer_dist=None,
-           no_scripts=None,
-           no_plugins=None,
-           optimize=None,
-           no_dev=None,
-           quiet=False,
-           composer_home='/root',
-           env=None):
-    '''
+def update(
+    name,
+    composer=None,
+    php=None,
+    user=None,
+    prefer_source=None,
+    prefer_dist=None,
+    no_scripts=None,
+    no_plugins=None,
+    optimize=None,
+    no_dev=None,
+    quiet=False,
+    composer_home="/root",
+    env=None,
+):
+    """
     Composer update the directory to ensure we have the latest versions
     of all project dependencies.
 
@@ -242,11 +249,11 @@ def update(name,
 
     env
         A list of environment variables to be set prior to execution.
-    '''
-    ret = {'name': name, 'result': None, 'comment': '', 'changes': {}}
+    """
+    ret = {"name": name, "result": None, "comment": "", "changes": {}}
 
     # Check if composer.lock exists, if so we already ran `composer install`
-    is_installed = __salt__['composer.did_composer_install'](name)
+    is_installed = __salt__["composer.did_composer_install"](name)
     if is_installed:
         old_status = "composer install has not yet been run in {0}".format(name)
     else:
@@ -254,17 +261,17 @@ def update(name,
 
     # The state of the system does need to be changed. Check if we're running
     # in ``test=true`` mode.
-    if __opts__['test'] is True:
-        ret['comment'] = 'The state of "{0}" will be changed.'.format(name)
-        ret['changes'] = {
-            'old': old_status,
-            'new': 'composer install/update will be run in {0}'.format(name)
+    if __opts__["test"] is True:
+        ret["comment"] = 'The state of "{0}" will be changed.'.format(name)
+        ret["changes"] = {
+            "old": old_status,
+            "new": "composer install/update will be run in {0}".format(name),
         }
-        ret['result'] = None
+        ret["result"] = None
         return ret
 
     try:
-        call = __salt__['composer.update'](
+        call = __salt__["composer.update"](
             name,
             composer=composer,
             php=php,
@@ -277,25 +284,24 @@ def update(name,
             no_dev=no_dev,
             quiet=quiet,
             composer_home=composer_home,
-            env=env
+            env=env,
         )
     except (SaltException) as err:
-        ret['result'] = False
-        ret['comment'] = 'Error executing composer in \'{0}\': {1}'.format(name, err)
+        ret["result"] = False
+        ret["comment"] = "Error executing composer in '{0}': {1}".format(name, err)
         return ret
 
     # If composer retcode != 0 then an exception was thrown and we dealt with it.
     # Any other case is success, regardless of what composer decides to output.
 
-    ret['result'] = True
+    ret["result"] = True
 
     if quiet is True:
-        ret['comment'] = 'Composer update completed successfully, output silenced by quiet flag'
+        ret[
+            "comment"
+        ] = "Composer update completed successfully, output silenced by quiet flag"
     else:
-        ret['comment'] = 'Composer update completed successfully'
-        ret['changes'] = {
-            'stderr': call['stderr'],
-            'stdout': call['stdout']
-        }
+        ret["comment"] = "Composer update completed successfully"
+        ret["changes"] = {"stderr": call["stderr"], "stdout": call["stdout"]}
 
     return ret
